@@ -165,6 +165,27 @@ my %res = (
  '\P{IsZenkaku}'   =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0)],
  '[[:^zenkaku:]]'  =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0)],
  '[^[:zenkaku:]]'  =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0)],
+ '\p{IsX0201}'     =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0)],
+ '[[:x0201:]]'     =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0)],
+ '[^[:^x0201:]]'   =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0)],
+ '\P{IsX0201}'     =>[qw(0 0 0 1 0 0 0 0 0 0 0 1 1 1 1 1 1 1 0 0 1 1 1 1 1 1)],
+ '[[:^x0201:]]'    =>[qw(0 0 0 1 0 0 0 0 0 0 0 1 1 1 1 1 1 1 0 0 1 1 1 1 1 1)],
+ '[^[:x0201:]]'    =>[qw(0 0 0 1 0 0 0 0 0 0 0 1 1 1 1 1 1 1 0 0 1 1 1 1 1 1)],
+ '[[:x0201:][:x0208:]]'
+		   =>[qw(1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0)],
+ '[^[:x0201:][:x0208:]]'
+		   =>[qw(0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1)],
+ '[\x20-\x7F\xA1-\xDF]'
+		   =>[qw(0 0 1 0 1 0 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0)],
+ '[^\x20-\x7F\xA1-\xDF]'
+		   =>[qw(1 1 0 1 0 1 0 0 0 0 0 1 1 1 1 1 1 1 0 0 1 1 1 1 1 1)],
+
+ '\p{IsX0208}'     =>[qw(0 0 0 1 0 0 0 0 0 0 0 1 1 1 1 1 1 1 0 0 1 1 1 1 1 0)],
+ '[[:x0208:]]'     =>[qw(0 0 0 1 0 0 0 0 0 0 0 1 1 1 1 1 1 1 0 0 1 1 1 1 1 0)],
+ '[^[:^x0208:]]'   =>[qw(0 0 0 1 0 0 0 0 0 0 0 1 1 1 1 1 1 1 0 0 1 1 1 1 1 0)],
+ '\P{IsX0208}'     =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 1)],
+ '[[:^x0208:]]'    =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 1)],
+ '[^[:x0208:]]'    =>[qw(1 1 1 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 1)],
 
  '\p{InLatin}'     =>[qw(0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0)],
  '[[:latin:]]'     =>[qw(0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0)],
